import {
  select,
  csv,
  scaleLinear,
  scaleTime,
  extent,
  axisLeft,
  axisBottom,
  format,
  line,
  area,
  curveBasis
} from 'd3';
//declaring variables 
const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

const xAxisTickFormat = number =>
    format('.3s')(number)

const render = data => {
  
  const xValue = d => d.year;
  const xAxisLabel = 'Year';
  
  const yValue = d => d.Accidents;
  const circleRadius = 7;
  const yAxisLabel = 'Accidents';
  
  const margin = { top: 10, right: 40, bottom: 120, left: 150 };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;  
  
// Determing the Scale for X axis
  const xScale = scaleLinear()
    .domain(extent(data, xValue))
    .range([0, innerWidth])
    .nice();
// Determing the Scale for Y axis  
  const yScale = scaleLinear()
    .domain(extent(data, yValue))
    .range([innerHeight, 0])
    .nice();
 // POsitioning the svg element   
  const g = svg.append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`);
 // Assigning values to x axis 
  const xAxis = axisBottom(xScale)
    .tickSize(-innerHeight)
    .tickPadding(15);
  
 // Assigning values to y axis  
  const yAxis = axisLeft(yScale)
    .tickSize(-innerWidth)
    .tickPadding(10)
    .tickFormat(xAxisTickFormat);
  
  const yAxisG = g.append('g').call(yAxis);
  yAxisG.selectAll('.domain').remove();
  // assigning label for y axis
  yAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', -93)
      .attr('x', -innerHeight / 2)
      .attr('transform', `rotate(-90)`)
      .attr('text-anchor', 'middle')
      .text(yAxisLabel);
  
  const xAxisG = g.append('g').call(xAxis)
    .attr('transform', `translate(0,${innerHeight})`);
  //assigning label for x axis
  xAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', 75)
      .attr('x', innerWidth / 2)
      .text(xAxisLabel);
 // To draw the line on the curve   and adding it to svg 
  const lineGenerator = line()
  	.x(d => xScale(xValue(d)))
  	.y(d => yScale(yValue(d)))
  	.curve(curveBasis);
 // To draw the area under the curve and adding it to svg 
  const areaGenerator = area()
  	.x(d => xScale(xValue(d)))
  	.y0(innerHeight)
  	.y1(d => yScale(yValue(d)))
  	.curve(curveBasis);
  // generating linechart for the data 
  g.append('path')
  	.attr('class', 'line-chart')
  	.attr('d', lineGenerator(data));
  // generating areachart for the data 
  g.append('path')
  	.attr('class', 'area-chart')
  	.attr('d', areaGenerator(data));
  
 
};
// Loading and Parsing CSV data
csv('https://gist.githubusercontent.com/BVNPK001/ecab90884139fbd6ba7faac778272bcc/raw/8d8437e6437e506d501b55739beb600f77e1b02b/AccidentsUSA')
  .then(data => {
    data.forEach(d => {
      d.Accidents = +d.Accidents;
//Formatting to retrieve year
      d.year = +d.year;
    });
    render(data);
  	console.log(data);
  });